@@ -30,6 +30,7 @@ from zope.interface import Interface, Attribute
 from zope.location.interfaces import IContained
 from zope.authentication.interfaces import IAuthentication, ILogout
 
+from schooltool.app.utils import vocabulary
 from schooltool.common.fields import Image
 from schooltool.common import SchoolToolMessage as _
 from schooltool.person.interfaces import ICalendarDisplayPreferences
@@ -145,6 +146,11 @@ class IApplicationPreferences(ICalendarDisplayPreferences):
         format="JPEG",
         required=False)
 
+    name_sorting = zope.schema.Choice(
+        title=_('Name sorting'),
+        vocabulary=vocabulary([('first_name', _('First name')),
+                               ('last_name', _('Last name'))]))
+
 
 class IApplicationTabs(Interface):
     """Tab visible settings stored in an annotation on SchoolToolApplication."""
