@@ -22,6 +22,11 @@ import unittest
 import doctest
 
 from zope.app.testing import setup
+from zope.component import provideAdapter
+from zope.interface import implements
+
+from schooltool.app.interfaces import ISchoolToolApplication
+from schooltool.app.interfaces import IApplicationPreferences
 
 
 def doctest_BasicPerson():
@@ -36,7 +41,7 @@ def doctest_BasicPerson():
          True
 
          >>> person.title
-         'Johnson, Peter'
+         'Peter Johnson'
 
     """
 
@@ -52,13 +57,32 @@ def doctest_PersonFactoryUtility():
         >>> verifyObject(IPersonFactory, factory)
         True
 
+        >>> class AppStub(object):
+        ...     implements(ISchoolToolApplication, IApplicationPreferences)
+        ...     def __init__(self):
+        ...         self.name_sorting = 'last_name'
+        >>> app = AppStub()
+        >>> provideAdapter(lambda _: app,
+        ...                adapts=(None, ), provides=ISchoolToolApplication)
+
+        >>> for column in factory.columns():
+        ...     print "%s, %s" % (column.name, column.title)
+        last_name, Last Name
+        first_name, First Name
+
+        >>> factory.sortOn()
+        (('last_name', False), ('first_name', False))
+
+    If we change name sorting order, both the sort and column order changes:
+
+        >>> app.name_sorting = 'first_name'
         >>> for column in factory.columns():
         ...     print "%s, %s" % (column.name, column.title)
         first_name, First Name
         last_name, Last Name
 
         >>> factory.sortOn()
-        (('last_name', False),)
+        (('first_name', False), ('last_name', False))
 
     """
 
@@ -73,9 +97,9 @@ def doctest_PersonFactoryUtility_createManagerUser():
 
     The title of the manager user is set to "Administratorius" + system name:
 
-        >>> manager = utility.createManagerUser("manager_username", "SchoolTool")
+        >>> manager = utility.createManagerUser("manager_username")
         >>> manager.title
-        'Administrator, SchoolTool'
+        'Default Manager'
         >>> manager.username
         'manager_username'
 
