@@ -13,15 +13,16 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 csv importing.
-
-$Id$
 """
-from schooltool.app.browser.csvimport import BaseCSVImporter, BaseCSVImportView
+from zope.traversing.browser.absoluteurl import absoluteURL
+
+from schooltool.app.browser.csvimport import BaseCSVImporter
+from schooltool.app.browser.csvimport import BaseCSVImportView
+from schooltool.app.browser.csvimport import FlourishBaseCSVImportView
 from schooltool.resource.resource import Resource, Location
 
 from schooltool.common import SchoolToolMessage as _
@@ -69,3 +70,11 @@ class ResourceCSVImportView(BaseCSVImportView):
     """View for Resource CSV importer."""
 
     importer_class = ResourceCSVImporter
+
+
+class FlourishResourceCSVImportView(FlourishBaseCSVImportView):
+
+    importer_class = ResourceCSVImporter
+
+    def nextURL(self):
+        return absoluteURL(self.context, self.request)
