@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Period and time slot schedule templates.
@@ -112,12 +111,10 @@ class WeekDayTemplates(DayTemplateSchedule):
     implements(interfaces.IWeekDayTemplates)
 
     def getWeekDayKey(self, weekday):
-        return u'%d' % weekday
+        return unicode(weekday)
 
     def getWeekDay(self, weekday):
-        assert self.templates is not None
-        key = self.getWeekDayKey(weekday)
-        return self.templates.get(key, None)
+        return self.templates.get(unicode(weekday), None)
 
     def iterDates(self, dates):
         if not self.templates:
