@@ -13,16 +13,13 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Pluggable Traverser Interfaces
 
 This implementation is independent of the presentation type. Sub-interfaces
 must be written for every specific presentation type.
-
-$Id$
 """
 
 from zope.interface import Interface, Attribute
